@@ -858,7 +858,7 @@ void generate_items_for_action_option_combo_box (const gchar *preset_choice)
             add_inside_txt = _("Add Inside Currently Selected Restart Action");
         }
         else { // SessionLogout
-            add_inside_txt = _("Add Inside Currently Selected SessionLogut Action");
+            add_inside_txt = _("Add Inside Currently Selected SessionLogout Action");
         }
     }
 
