@@ -340,7 +340,7 @@ void create_context_menu (GdkEventButton *event)
                 }
 
                 for (guint8 actions_cnt = 0; actions_cnt < NUMBER_OF_ACTIONS; ++actions_cnt) {
-                    const gchar *menu_item_txts[] = { N_("Add Execute"), N_("Add Exit"), N_("Add Reconfigure"), N_("Add Restart"), N_("Add SessionLogut") };
+                    const gchar *menu_item_txts[] = { N_("Add Execute"), N_("Add Exit"), N_("Add Reconfigure"), N_("Add Restart"), N_("Add SessionLogout") };
 
                     menu_item = gtk_menu_item_new_with_label (_(menu_item_txts[actions_cnt]));
 
